@@ -87,11 +87,11 @@ def runList(*taskList):
 
         msgAry = ["任务结束"]
         if b.countLogCritical:
-            msgAry.append("critical({b.countLogCritical})")
+            msgAry.append(f"critical({b.countLogCritical})")
         if b.countLogError:
-            msgAry.append("error({b.countLogError})")
+            msgAry.append(f"error({b.countLogError})")
         if b.countLogWarning:
-            msgAry.append("warning({b.countLogWarning})")
+            msgAry.append(f"warning({b.countLogWarning})")
 
         b.info(" ".join(msgAry))
         passTime = str(datetime.datetime.now() - startTime)
